@@ -17,6 +17,14 @@ STATUS_COLORS = {
 }
 
 
+class OIHelperRuntimeError(Exception):
+    def __init__(self, message=None) -> None:
+        if message:
+            self.message = message
+        self.message = "An unexpected error happened during execution. There should be more expansions above."
+        super().__init__(self.message)
+
+
 def get_testcase_no(testcase: str) -> int:
     testcase_no = 0
     custom_testcase_tester = re.compile("\w+\d+-\d+.\w+")
