@@ -45,14 +45,13 @@ class Judger(object):
 
     def compile_program(self, program_path: str, output_path: str = "./output") -> None:
         compile_process = subprocess.Popen(
-            f'{self.compiler_path} "{program_path}" -o "{output_path}"',
-            shell=True,
+            [self.compiler_path, program_path, "-o", output_path],
         )
         compile_process.wait()
         if compile_process.returncode != 0:
             raise RuntimeError(
                 "Failed to compile. "
-                f"There should be more error messages produced by the compiler above."
+                "There should be more error messages produced by the compiler above."
             )
 
     def run_program(
@@ -65,7 +64,6 @@ class Judger(object):
     ) -> None:
         runner_process = subprocess.Popen(
             exec_path,
-            shell=True,
             stdin=stdin,
             stdout=subprocess.PIPE,
             stderr=subprocess.PIPE,
@@ -110,6 +108,7 @@ class Judger(object):
             }
 
         expected_output = stdout.read().rstrip("\n")
+        program_output_original = program_output
         program_output = program_output.splitlines(True)
         for i, expected in enumerate(expected_output.splitlines(True)):
             if i >= len(program_output):
@@ -117,6 +116,8 @@ class Judger(object):
                     "status": "WA",
                     "details": f"Wrong answer on line {i} column 0, "
                     f"reading EOF, expected {expected[0]}.",
+                    "program_output": program_output_original,
+                    "expected_output": expected_output,
                 }
             output = program_output[i]
             result = self._assert_equal(output, expected)
@@ -128,6 +129,8 @@ class Judger(object):
                     "status": "WA",
                     "details": f"Wrong answer on line {i} column {pos}, "
                     f"reading {cur_output}, expected {cur_expected}.",
+                    "program_output": program_output_original,
+                    "expected_output": expected_output,
                 }
 
         return {
