@@ -10,7 +10,7 @@ class LuoguParser(object):
     def parse_problem(self, pid: str):
         response = requests.get(
             f"https://www.luogu.com.cn/problem/{pid.upper()}?_contentOnly=1",
-            headers={"User-Agent": USER_AGENT}
+            headers={"User-Agent": USER_AGENT},
         ).json()["currentData"]["problem"]
         testcases: list[list[str, str]] = response["samples"]
         time_limit: int = max(response["limits"]["time"])
